// popup menu

// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.mnfc;

import netscape.application.*;

/**

   IPopupMenu is a popup menu with automatic location adjustment
   (it tries to stay within the display area).

   * @author Makoto Nagata, MicroNova
   * @version 1.0

*/

public class IPopupMenu extends MenuView
{
    /**

       Creates a popup menu window with the given menu structure.
       The default type is MenuView.VERTICAL.

    */

    public IPopupMenu(Menu menu)
    {
        super(menu);

        this.setType(MenuView.VERTICAL);

        this.sizeToMinSize();
    }

    /**

       Shows this popup menu at (x, y) in the given view's coordinate system.

    */

    public void show(View view, int x, int y)
    {
        RootView rootView = view.rootView();

        Point p = view.convertToView(rootView(), x, y);

        MouseEvent rootEvent = new MouseEvent();

        rootEvent.x = p.x;
        rootEvent.y = p.y;

        super.show(rootView, rootEvent);
    }

    /**
       
       Overridden to make location adjustment possible.
       <BR>
       Creates <A HREF="com.micronova.mnfc.IPopupMenuWindow.html">IPopupMenuWindow</A> instead of InternalWindow.
       <BR><BR>

     */

    protected InternalWindow createMenuWindow()
    {
        IPopupMenuWindow window = new IPopupMenuWindow(this);

        window.setType(InternalWindow.BLANK_TYPE);
        window.setLayer(InternalWindow.IGNORE_WINDOW_CLIPVIEW_LAYER + 11);
        window.setCanBecomeMain(false);
        window.contentView().setTransparent(true);
        window.setScrollsToVisible(true);

        return window;
    }

    /**
       
       Overridden to make location adjustment possible.
       <BR>
       Creates IPopupMenu instead of MenuView.
       <BR><BR>

     */

    protected MenuView createMenuView(Menu theMenu)
    {
        IPopupMenu menuView = new IPopupMenu(theMenu);
        menuView.setOwner(this);

        return menuView;
    }
}
