// popup menu window, with auto-adjustment

// Copyright (C) 1999 by Makoto Nagata, MicroNova <mnagata@micronova.com>.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// Visit http://www.micronova.com for updates

package com.micronova.mnfc;

import netscape.application.*;

/**

   IPopupMenuWindow is an InternalWindow used for popup menu display.
   IPopupMenuWindow adjusts its window position to stay within
   the rootView when its rootView is set.

   * @author Makoto Nagata, MicroNova
   * @version 1.0

*/

public class IPopupMenuWindow extends InternalWindow
{
    /** menuView that is contained in this window */

    protected MenuView menuView;

    /**

       Constructs an IPopupMenuWindow for a given MenuView.

    */

    public IPopupMenuWindow(MenuView menuView)
    {
        super();
        
        this.menuView = menuView;
    }

    /**

       Tries to adjust the window position to stay within the rootView.
       <BR><BR>

     */

    public void setRootView(RootView rootView)
    {
        super.setRootView(rootView);

        if (rootView != null)
        {
            int absoluteHeight = rootView.height();
            int absoluteWidth = rootView.width();
    
            Rect r = bounds();
        
            if (r.y > absoluteHeight - r.height)
            {
                r.y = absoluteHeight - r.height;
            }
        
            if (r.x > absoluteWidth - r.width)
            {
                MenuView owner = menuView.owner();
    
                r.x = absoluteWidth - r.width;
        
                if (owner != null)
                {
                    InternalWindow windowParent = IPopupMenuWindow.menuWindow(owner);
                    if (windowParent != null)
                    {
                        Rect rParent = windowParent.bounds();
     
                        r.x = rParent.x - r.width;
                    }
                }
            }
        
            moveTo(r.x, r.y);
        }
    }

    /**

       Locates the ancestor InternalWindow of a view.
       Internally used to locate the parent menu window.

     */

    protected static InternalWindow menuWindow(View view)
    {
        while ((view != null) && (!(view instanceof InternalWindow)))
        {
            view = view.superview();
        }

        return (InternalWindow)view;
    }
}
